@@ -1,12 +1,12 @@
 import { css } from '@emotion/css';
 
-import { GrafanaTheme2 } from '@grafana/data/';
-import { Stack, Text } from '@grafana/ui';
-import { useStyles2 } from '@grafana/ui/';
+import { GrafanaTheme2 } from '@grafana/data';
+import { Stack, Text, useStyles2 } from '@grafana/ui';
 import { t, Trans } from 'app/core/internationalization';
 
+import { Spec } from '../api/clients/banners';
+
 import { Banner } from './Banner';
-import { Spec } from './api';
 
 export type BannerPreviewProps = Pick<Spec, 'message' | 'variant'>;
 
